#!/usr/bin/env bash

info () {
    echo -e "\033[1m info:   \033[0m $@ ";
}

ok () {
    echo -e "\033[1m done:  \033[0m \033[32m $@ \033[0m";
}

error () {
    echo -e  "\033[1m ERROR:\033[0m \033[31m $@\033[0m";
}

CENTOSRELEASE=`cat /etc/redhat-release`
SUBSTR=`echo $CENTOSRELEASE|cut -c1-22`
SUBSTR2=`echo $CENTOSRELEASE|cut -c1-26`

#Check OS version
CentOsVersion=0
if [ "$SUBSTR" = "CentOS Linux release 8" ]
    then
        CentOsVersion=80
elif [ "$SUBSTR" = "CentOS Linux release 7" ]
    then
        CentOsVersion=70
elif [ "$SUBSTR2" == "CentOS release 6.5 (Final)" ]
    then
        CentOsVersion=65
elif [ "$SUBSTR2" == "CentOS release 6.4 (Final)" ]
    then
        CentOsVersion=64
else
    CentOsVersion=60
fi

read -p "dpiui2 will be completely removed… Are you sure??? (Enter yes or no)? " answer

if [ "$answer" != "yes" ]; then
  exit
fi

info "Disabling services..."
if [ "$CentOsVersion" -ge 70 ]
then
  systemctl disable mariadb.service && ok "systemctl disable mariadb.service;" || error "systemctl disable mariadb.service;"
	systemctl stop mariadb.service && ok "systemctl stop mariadb.servic;" || error "systemctl stop mariadb.service;"
	systemctl disable httpd.service && ok "systemctl disable httpd.service;" || error "systemctl disable httpd.service;"
	systemctl stop httpd.service && ok "systemctl stop httpd.service;" || error "systemctl stop httpd.service;"
	systemctl disable redis && ok "systemctl disable redis;" || error "systemctl disable redis;"
	systemctl stop redis && ok "systemctl stop redis;" || error "systemctl stop redis;"

	systemctl disable searchd && ok "systemctl disable searchd;" || error "systemctl disable searchd;"
	systemctl stop searchd && ok "systemctl stop searchd;" || error "systemctl stop searchd;"

	systemctl disable supervisord && ok "systemctl disable supervisord;" || error "systemctl disable supervisord;"
	systemctl stop supervisord && ok "systemctl stop supervisord;" || error "systemctl stop supervisord;"

	systemctl disable websocket && ok "systemctl disable websocket;" || error "systemctl disable websocket;"
	systemctl stop websocket && ok "systemctl stop websocket;" || error "systemctl stop websocket;"
else
  service mysql stop && ok "service mysql stop;" || error "service mysql stop;"
  chkconfig mysql off && ok "chkconfig mysql off;" || error "chkconfig mysql off;"
  service httpd stop && ok "service httpd stop;" || error "service httpd stop;"
  chkconfig httpd off && ok "chkconfig httpd off;" || error "chkconfig httpd off;"
  service redis stop && ok "service redis stop;" || error "service redis stop;"
  chkconfig redis off && ok "chkconfig redis off;" || error "chkconfig redis off;"

  service searchd stop && ok "service searchd stop;" || error "service searchd stop;"
  chkconfig searchd off && ok "chkconfig searchd off;" || error "chkconfig searchd off;"

  service supervisord stop && ok "service supervisord stop;" || error "service supervisord stop;"
  chkconfig supervisord off && ok "chkconfig supervisord off;" || error "chkconfig supervisord off;"

  service websocket stop && ok "service websocket stop;" || error "service websocket stop;"
  chkconfig websocket off && ok "chkconfig websocket off;" || error "chkconfig websocket off;"

fi

info "Remove cron jobs..."
crontab -l > allcrons
sed -i '/artisan/d' allcrons
sed -i '/supervisord/d' allcrons
crontab allcrons
rm -f allcrons


info "Disabling ports..."
FRONT_PORT=443
BACK_PORT=9999
REDIS_PORT=6379
SOCKET_PORT=8090

if [ "$CentOsVersion" -ge 70 ]
then
        firewall-cmd --permanent --remove-port=80/tcp
        firewall-cmd --permanent --remove-port=443/tcp
        firewall-cmd --permanent --remove-port=$FRONT_PORT/tcp
        firewall-cmd --permanent --remove-port=$BACK_PORT/tcp
        firewall-cmd --permanent --remove-port=$REDIS_PORT/tcp
        firewall-cmd --permanent --remove-port=$SOCKET_PORT/tcp
        firewall-cmd --reload
else
    iptables -D INPUT -p tcp -m tcp --dport 80 -j ACCEPT
    iptables -D INPUT -p tcp -m tcp --dport 443 -j ACCEPT
    iptables -D INPUT -p tcp -m tcp --dport $FRONT_PORT -j ACCEPT
    iptables -D INPUT -p tcp -m tcp --dport $BACK_PORT -j ACCEPT
    iptables -D INPUT -p tcp -m tcp --dport $REDIS_PORT -j ACCEPT
    iptables -D INPUT -p tcp -m tcp --dport $SOCKET_PORT -j ACCEPT
    service iptables save
    service iptables restart
fi

info "Remove rpms dpiui2, supervisord, httpd..."
yum remove -y dpiui2 httpd supervisor httpd sphinx mariadb MariaDB-server nmap nodejs php redis libssh2 libssh2-devel

rm -rf /var/www/html/dpiui2

rm -- "$0"